@@ -43,7 +43,6 @@ Molmasscalculator::Molmasscalculator(QObject *parent, const QVariantList &args)
         m_MassLabel(0),
         m_switchButton(0)
 {
-    KGlobal::locale()->insertCatalog("kalzium");
     // Some Applet settings
     setAspectRatioMode(Plasma::IgnoreAspectRatio);
     setHasConfigurationInterface(true);
@@ -158,7 +157,7 @@ QGraphicsWidget *Molmasscalculator::graphicsWidget()
     m_MassLabel->setStyleSheet(css);
 
     m_lineedit = new Plasma::LineEdit();
-    m_lineedit->setClearButtonShown(true);
+    m_lineedit->setClearButtonEnabled(true);
     m_lineedit->setMinimumWidth(100);
     m_lineedit->setText(i18n("C2H5OH"));
     connect(m_lineedit, SIGNAL(textEdited(QString)), m_triggerTimer, SLOT(start()));
